/**
 * Colors
 */
/**
 * Breakpoints & Media Queries
 */
/**
 * SCSS Variables.
 *
 * Please use variables from this sheet to ensure consistency across the UI.
 * Don't add to this sheet unless you're pretty sure the value will be reused in many places.
 * For example, don't add rules to this sheet that affect block visuals. It's purely for UI.
 */
/**
 * Colors
 */
/**
 * Fonts & basic variables.
 */
/**
 * Grid System.
 * https://make.wordpress.org/design/2019/10/31/proposal-a-consistent-spacing-system-for-wordpress/
 */
/**
 * Dimensions.
 */
/**
 * Shadows.
 */
/**
 * Editor widths.
 */
/**
 * Block & Editor UI.
 */
/**
 * Block paddings.
 */
/**
 * React Native specific.
 * These variables do not appear to be used anywhere else.
 */
/**
 * Breakpoint mixins
 */
/**
 * Long content fade mixin
 *
 * Creates a fading overlay to signify that the content is longer
 * than the space allows.
 */
/**
 * Focus styles.
 */
/**
 * Applies editor left position to the selector passed as argument
 */
/**
 * Styles that are reused verbatim in a few places
 */
/**
 * Allows users to opt-out of animations via OS-level preferences.
 */
/**
 * Reset default styles for JavaScript UI based pages.
 * This is a WP-admin agnostic reset
 */
/**
 * Reset the WP Admin page styles for Gutenberg-like pages.
 */
/**
 * These are default block editor widths in case the theme doesn't provide them.
 */
/**
* Editor Normalization Styles
*
* These are only output in the editor, but styles here are prefixed .editor-styles-wrapper and affect the theming
* of the editor by themes.
* Why do these exist? Why not rely on browser defaults?
* These styles are necessary so long as CSS can bleed from the wp-admin into the editing canvas itself.
* Let's continue working to refactor these away, whether through Shadow DOM or better scoping of upstream styles.
*/
body {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  font-size: 16px;
  line-height: 1.8;
  color: #1e1e1e;
  padding: 10px;
}

.block-editor-block-list__layout.is-root-container > .wp-block[data-align=full] {
  margin-left: -10px;
  margin-right: -10px;
}

/* Headings */
h1,
h2,
h3 {
  line-height: 1.4;
}

h1 {
  font-size: 2.44em;
  margin-top: 0.67em;
  margin-bottom: 0.67em;
}

h2 {
  font-size: 1.95em;
  margin-top: 0.83em;
  margin-bottom: 0.83em;
}

h3 {
  font-size: 1.56em;
  margin-top: 1em;
  margin-bottom: 1em;
}

h4 {
  font-size: 1.25em;
  line-height: 1.5;
  margin-top: 1.33em;
  margin-bottom: 1.33em;
}

h5 {
  font-size: 1em;
  margin-top: 1.67em;
  margin-bottom: 1.67em;
}

h6 {
  font-size: 0.8em;
  margin-top: 2.33em;
  margin-bottom: 2.33em;
}

h1,
h2,
h3,
h4,
h5,
h6 {
  color: inherit;
}

p {
  font-size: inherit;
  line-height: inherit;
  margin-top: 28px;
  margin-bottom: 28px;
}

ul,
ol {
  margin-bottom: 28px;
  padding-left: 1.3em;
  margin-left: 1.3em;
}
ul ul,
ul ol,
ol ul,
ol ol {
  margin-bottom: 0;
}
ul li,
ol li {
  margin-bottom: initial;
}

ul {
  list-style-type: disc;
}

ol {
  list-style-type: decimal;
}

ul ul,
ol ul {
  list-style-type: circle;
}

.wp-align-wrapper {
  max-width: 840px;
}
.wp-align-wrapper > .wp-block, .wp-align-wrapper.wp-align-full {
  max-width: none;
}
.wp-align-wrapper.wp-align-wide {
  max-width: 840px;
}

a {
  transition: none;
}

code,
kbd {
  padding: 0;
  margin: 0;
  background: inherit;
  font-size: inherit;
  font-family: monospace;
}