/**
 * Colors
 */
/**
 * Breakpoints & Media Queries
 */
/**
 * SCSS Variables.
 *
 * Please use variables from this sheet to ensure consistency across the UI.
 * Don't add to this sheet unless you're pretty sure the value will be reused in many places.
 * For example, don't add rules to this sheet that affect block visuals. It's purely for UI.
 */
/**
 * Colors
 */
/**
 * Fonts & basic variables.
 */
/**
 * Grid System.
 * https://make.wordpress.org/design/2019/10/31/proposal-a-consistent-spacing-system-for-wordpress/
 */
/**
 * Dimensions.
 */
/**
 * Shadows.
 */
/**
 * Editor widths.
 */
/**
 * Block & Editor UI.
 */
/**
 * Block paddings.
 */
/**
 * React Native specific.
 * These variables do not appear to be used anywhere else.
 */
/**
 * Breakpoint mixins
 */
/**
 * Long content fade mixin
 *
 * Creates a fading overlay to signify that the content is longer
 * than the space allows.
 */
/**
 * Focus styles.
 */
/**
 * Applies editor left position to the selector passed as argument
 */
/**
 * Styles that are reused verbatim in a few places
 */
/**
 * Allows users to opt-out of animations via OS-level preferences.
 */
/**
 * Reset default styles for JavaScript UI based pages.
 * This is a WP-admin agnostic reset
 */
/**
 * Reset the WP Admin page styles for Gutenberg-like pages.
 */
/**
 * These are default block editor widths in case the theme doesn't provide them.
 */
:root {
  --wp-admin-theme-color: #007cba;
  --wp-admin-theme-color-darker-10: #006ba1;
  --wp-admin-theme-color-darker-20: #005a87;
  --wp-admin-border-width-focus: 2px;
}
@media (-webkit-min-device-pixel-ratio: 2), (min-resolution: 192dpi) {
  :root {
    --wp-admin-border-width-focus: 1.5px;
  }
}

.block-directory-block-ratings {
  display: flex;
}
.block-directory-block-ratings > div {
  line-height: 1;
  display: flex;
}
.block-directory-block-ratings .block-directory-block-ratings__rating-count {
  font-size: ms(-2);
}
.block-directory-block-ratings svg {
  fill: #ffb900;
}

.block-directory-compact-list {
  margin: 0;
  list-style: none;
}

.block-directory-compact-list__item {
  display: flex;
  flex-direction: row;
  align-items: center;
  margin-bottom: 16px;
}
.block-directory-compact-list__item:last-child {
  margin-bottom: 0;
}

.block-directory-compact-list__item-details {
  margin-left: 8px;
}

.block-directory-compact-list__item-title {
  font-weight: 500;
}

.block-directory-compact-list__item-author {
  color: #757575;
  font-size: 11px;
}

.block-directory-downloadable-block-author-info__content {
  font-size: 12px;
}

.block-directory-downloadable-block-author-info__content-author {
  margin-bottom: 4px;
  font-size: 13px;
}

.block-directory-downloadable-block-header__row {
  display: flex;
  flex-grow: 1;
}
.block-directory-downloadable-block-header__row .block-directory-downloadable-block-header__column {
  display: flex;
  flex-direction: column;
  flex-grow: 1;
  padding-left: 12px;
}

.block-directory-downloadable-block-header__title {
  margin: 0;
  font-size: 13px;
  color: currentColor;
}

.block-directory-downloadable-block-icon {
  width: 36px;
  height: 36px;
}
.block-directory-downloadable-block-icon .block-editor-block-icon {
  width: 36px;
  height: 36px;
  font-size: 36px;
  background-color: #ddd;
}
.block-directory-downloadable-block-icon > img {
  width: 100%;
}

.block-directory-downloadable-block-info__content {
  margin: 0 0 16px;
  font-size: 13px;
}

.block-directory-downloadable-block-info__meta {
  display: flex;
  align-items: center;
  margin-bottom: 2px;
  color: #757575;
  font-size: 12px;
}

.block-directory-downloadable-block-info__meta:last-child {
  margin-bottom: 0;
}

.block-directory-downloadable-block-info__icon {
  margin-right: 4px;
  fill: #757575;
}

.block-directory-downloadable-block-list-item {
  width: 100%;
  padding: 0;
  margin: 0;
  display: flex;
  flex-direction: row;
  font-size: 13px;
  color: #1e1e1e;
  align-items: flex-start;
  justify-content: center;
  background: transparent;
  word-break: break-word;
  border-top: 1px solid #ddd;
  border-bottom: 1px solid #ddd;
  transition: all 0.05s ease-in-out;
  position: relative;
  text-align: left;
  overflow: hidden;
}
@media (prefers-reduced-motion: reduce) {
  .block-directory-downloadable-block-list-item {
    transition-duration: 0s;
  }
}
.block-directory-downloadable-block-list-item + .block-directory-downloadable-block-list-item {
  border-top: none;
}

.block-directory-downloadable-block-list-item:last-child:not(:only-of-type) {
  border-top: 0;
}

.block-directory-downloadable-block-list-item:last-child {
  border-bottom: 0;
}

.block-directory-downloadable-block-list-item__panel {
  display: flex;
  flex-grow: 1;
  flex-direction: column;
}

.block-directory-downloadable-block-list-item__header {
  display: flex;
  flex-direction: column;
  padding: 16px 16px 0;
}

.block-directory-downloadable-block-list-item__body {
  display: flex;
  flex-direction: column;
  padding: 16px;
}

.block-directory-downloadable-block-list-item__footer {
  display: flex;
  flex-direction: column;
  padding: 16px;
  background-color: #f0f0f0;
}

.block-directory-downloadable-block-list-item__content {
  color: #757575;
}

.block-directory-downloadable-block-notice {
  margin: 0 0 16px;
}

.block-directory-downloadable-block-notice__content {
  padding-right: 12px;
  margin-bottom: 8px;
}

.block-directory-downloadable-blocks-list {
  list-style: none;
  margin: 0;
  overflow: hidden;
  display: flex;
  flex-wrap: wrap;
}

.block-directory-downloadable-blocks-panel__description {
  font-style: italic;
  padding: 16px;
  margin: 0;
  text-align: left;
  color: #757575;
}

.block-directory-downloadable-blocks-panel__description.has-no-results {
  font-style: normal;
  padding: 0;
  margin: 112px 0;
  text-align: center;
  color: #757575;
}
.block-directory-downloadable-blocks-panel__description.has-no-results .components-spinner {
  float: inherit;
}

.installed-blocks-pre-publish-panel__copy {
  margin-top: 0;
}