.wp-block-file {

	.wp-block-file__textlink {
		text-decoration: underline;
		text-decoration-style: solid;
		text-decoration-thickness: 1px;

		&:hover {
			text-decoration: underline;
			text-decoration-style: dotted;
		}
	}

	.wp-block-file__button {
		// Extend button style
		@include button-style();
		display: inline-block;
		
		// Remove :focus styles in the editor
		&:focus {
			outline-offset: inherit;
			outline: inherit;
		}
	}
}
