.button,
button,
input[type="button"],
input[type="reset"],
input[type="submit"] {

	@include button-transition;
	background: $color__background-button;
	border: none;
	border-radius: 5px;
	box-sizing: border-box;
	color: $color__background-body;
	@include font-family( $font__heading );
	font-size: $font__size-sm;
	font-weight: 700;
	line-height: $font__line-height-heading;
	outline: none;
	padding: ( $size__spacing-unit * .76 ) $size__spacing-unit;
	text-decoration: none;
	vertical-align: bottom;

	&:hover {
		background: $color__background-button-hover;
		cursor: pointer;
	}

	&:visited {
		color: $color__background-body;
		text-decoration: none;
	}

	&:focus {
		background: $color__background-button-hover;
		outline: thin dotted;
		outline-offset: -4px;
	}
}
