/**
 * These styles should be loaded by the Block Editor only
 */
@import "01-settings/fonts";
@import "01-settings/global";

@import "02-tools/mixins";
@import "02-tools/functions";

@import "03-generic/breakpoints";

@import "04-elements/blockquote";
@import "04-elements/media";
@import "04-elements/forms-editor";
@import "04-elements/links";

@import "05-blocks/blocks-editor";

@import "06-components/editor";

@import "07-utilities/color-palette";
